@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     ForeignKey,
+    Boolean,
 )
 from datetime import datetime
 
@@ -30,6 +31,7 @@ class CompanyFilingModel(Base):
         nullable=False,
     )
     type = Column(String(50), nullable=False)
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
